This is an automated email from the ASF dual-hosted git repository.

masaori pushed a commit to branch quic-latest
in repository https://gitbox.apache.org/repos/asf/trafficserver.git


The following commit(s) were added to refs/heads/quic-latest by this push:
     new 6d8eee5  Rename buffer for received STREAM frame
6d8eee5 is described below

commit 6d8eee58fb8abdff2e796c0f1a9f12ba64ec37f6
Author: Masaori Koshiba <masa...@apache.org>
AuthorDate: Wed Sep 6 16:35:15 2017 +0900

    Rename buffer for received STREAM frame
---
 iocore/net/quic/QUICStream.cc | 10 +++++-----
 iocore/net/quic/QUICStream.h  |  2 +-
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/iocore/net/quic/QUICStream.h b/iocore/net/quic/QUICStream.h
index 0c3e73b..ff7bb14 100644
--- a/iocore/net/quic/QUICStream.h
+++ b/iocore/net/quic/QUICStream.h
@@ -105,7 +105,7 @@ private:
 
   // Fragments of received STREAM frame (offset is unmatched)
   // TODO: Consider to replace with ts/RbTree.h or other data structure
-  std::map<QUICOffset, std::shared_ptr<const QUICStreamFrame>> 
_request_stream_frame_buffer;
+  std::map<QUICOffset, std::shared_ptr<const QUICStreamFrame>> 
_received_stream_frame_buffer;
 
   QUICStreamManager *_stream_manager = nullptr;
   QUICFrameTransmitter *_tx          = nullptr;

diff --git a/iocore/net/quic/QUICStream.cc b/iocore/net/quic/QUICStream.cc
index c16d0dd..0ca060d 100644
--- a/iocore/net/quic/QUICStream.cc
+++ b/iocore/net/quic/QUICStream.cc
@@ -267,10 +267,10 @@ QUICStream::_write_to_read_vio(const 
std::shared_ptr<const QUICStreamFrame> &fra
 void
 QUICStream::_reorder_data()
 {
-  auto frame = _request_stream_frame_buffer.find(this->_recv_offset);
-  while (frame != this->_request_stream_frame_buffer.end()) {
+  auto frame = _received_stream_frame_buffer.find(this->_recv_offset);
+  while (frame != this->_received_stream_frame_buffer.end()) {
     this->_write_to_read_vio(frame->second);
-    frame = _request_stream_frame_buffer.find(this->_recv_offset);
+    frame = _received_stream_frame_buffer.find(this->_recv_offset);
   }
 }
 
@@ -310,9 +310,9 @@ QUICStream::recv(const std::shared_ptr<const 
QUICStreamFrame> frame)
     this->_write_to_read_vio(frame);
     this->_reorder_data();
   } else {
     // NOTE: push fragments in _request_stream_frame_buffer temporally.
     // They will be reordered when missing data is filled and offset is 
matched.
-    this->_request_stream_frame_buffer.insert(std::make_pair(frame->offset(), 
frame));
+    this->_received_stream_frame_buffer.insert(std::make_pair(frame->offset(), 
frame));
   }
 
@@ -310,9 +310,9 @@ QUICStream::recv(const std::shared_ptr<const 
     this->_reorder_data();
   } else {
-    // NOTE: push fragments in _request_stream_frame_buffer temporally.
+    // NOTE: push fragments in _received_stream_frame_buffer temporally.
     // They will be reordered when missing data is filled and offset is 
matched.
   return QUICError(QUICErrorClass::NONE);
-- 
To stop receiving notification emails like this one, please contact
['"commits@trafficserver.apache.org" <commits@trafficserver.apache.org>'].

Reply via email to